diff --git a/.gitignore b/.gitignore
index f00fed8..c932383 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,3 +1,4 @@
+.idea/*
data/*
!data/.gitkeep
plugins/*
diff --git a/assets/css/icecoder.css b/assets/css/icecoder.css
index 3ac2e21..56983d3 100644
--- a/assets/css/icecoder.css
+++ b/assets/css/icecoder.css
@@ -13,6 +13,7 @@ h2 {font-size: 18px; font-weight: normal; color: #fff}
.blackMask {position: fixed; display: table; width: 100%; height: 100%; top: 0; left: 0; visibility: hidden; background-color: rgba(0,0,0,0.8); text-align: center; z-index: 100}
.blackMask .popupVCenter {#position: absolute; display: table-cell; #top: 50%; vertical-align: middle; text-align: center}
.popupVCenter .popup {#position: relative; #top: -50%; text-align: center; color: #fff; font-size: 10px}
+.popupVCenter .popup .imgDisplay {border: solid 10px #fff; max-width: 700px; max-height: 500px; background-color: #000; background-image: url('../images/checkerboard.png')}
.floatingContainer {position: absolute; top: 0; left: 0; width: 55px; height: 55px; visibility: hidden; border: solid 1px #444; image-rendering: pixelated}
.floatingContainer:before {position: absolute; display: inline-block; width: 3px; height: 3px; left: 25px; top: 25px; content: ''; border: solid 1px #b00}
diff --git a/classes/File.php b/classes/File.php
index e9522a0..b392607 100644
--- a/classes/File.php
+++ b/classes/File.php
@@ -234,7 +234,7 @@ class File
parent.parent.document.getElementById(\'blackMask\').style.visibility = "visible";
parent.parent.document.getElementById(\'mediaContainer\').innerHTML =
"" +
- " 700 || this.naturalHeight > 500) ? \', ' .$t['displayed at'] . '\' + this.width + \' x \' + this.height : \'\'; document.getElementById(\'imgInfo\').innerHTML += \' (\' + this.naturalWidth + \' x \' + this.naturalHeight + reducedImgMsg + \')\'; ICEcoder.initCanvasImage(this); ICEcoder.interactCanvasImage(this)\">
" +
+ " 700 || this.naturalHeight > 500) ? \', ' .$t['displayed at'] . '\' + this.width + \' x \' + this.height : \'\'; document.getElementById(\'imgInfo\').innerHTML += \' (\' + this.naturalWidth + \' x \' + this.naturalHeight + reducedImgMsg + \')\'; ICEcoder.initCanvasImage(this); ICEcoder.interactCanvasImage(this)\">
" +
"
+
diff --git a/assets/js/icecoder.js b/assets/js/icecoder.js
index dd53e02..da7c4b4 100644
--- a/assets/js/icecoder.js
+++ b/assets/js/icecoder.js
@@ -10,8 +10,9 @@ var ICEcoder = {
// INIT
// ====
// URL we're viewing ICEcoder from
iceLoc: window.location.origin + window.location.pathname.replace(/\/$/, ""),
+ assetsLoc: get('icecoderJSFile').dataset.assetsRoot,
// Define settings
filesW: 250, // Width of files pane
@@ -4429,7 +4430,7 @@ var ICEcoder = {
this.openFiles.push(shortURL);
// Setup a new tab
- closeTabLink = '
';
+ closeTabLink = '
';
get('tab' + (this.openFiles.length)).style.display = "inline-block";
fileName = this.openFiles[this.openFiles.length - 1];
fileExt = fileName.substr(fileName.lastIndexOf(".") + 1);
@@ -4477,7 +4478,7 @@ var ICEcoder = {
this.openFiles[tabNum - 1] = newName;
// Setup a new tab
- closeTabLink = '
';
+ closeTabLink = '
';
fileName = this.openFiles[tabNum - 1];
fileExt = fileName.substr(fileName.lastIndexOf(".") + 1);
get('tab' + tabNum).innerHTML = closeTabLink + "" + fileName.slice(fileName.lastIndexOf("/")).replace(/\//, "");
@@ -5301,7 +5302,7 @@ var ICEcoder = {
"height": 55,
"top": -55,
"left": 0,
- "title": "
Code editor awesomeness ...in your browser",
+ "title": "
Code editor awesomeness ...in your browser",
"message": "View the quick start tutorial? (Well worthwhile!) or skip it.",
"button": "view tutorial"
@@ -10,8 +10,9 @@ var ICEcoder = {
// INIT
// ====
- // URL we're viewing ICEcoder from
+ // URLs we're viewing ICEcoder and its assets from
iceLoc: window.location.origin + window.location.pathname.replace(/\/$/, ""),
},